<h1 align="center">
  Swallow
</h1>
<h4 align="center">Used to swallow (send to the scratchpad) a terminal window after a blocking application is run in i3 window manager</h4>

<p align="center">
  <img src="https://img.shields.io/badge/Maintained%3F-Yes-green?style=for-the-badge">
  <img src="https://img.shields.io/github/license/jamesofarrell/i3-swallow?style=for-the-badge">
  <img src="https://img.shields.io/github/issues/jamesofarrell/i3-swallow?color=violet&style=for-the-badge">
  <img src="https://img.shields.io/github/stars/jamesofarrell/i3-swallow?style=for-the-badge">
  <img src="https://img.shields.io/github/forks/jamesofarrell/i3-swallow?color=teal&style=for-the-badge">
  <img src="https://github.com/jamesofarrell/i3-swallow/blob/master/Swallow.gif">
</p>

## Information

This repo just packages [jamesofarrell/i3-swallow](https://github.com/jamesofarrell/i3-swallow) script using [Poetry](https://python-poetry.org/)
so it can be install using `pip`

## Requirements

- Unix system with i3 window manager, or i3 compatible window manager such as sway
- Python3.x+
- Python3.x+ Pip

## Installation Instruction

```bash
pip install --user i3-swallow
```

## Usage

```bash
swallow -h
```

## License

This Project is licensed under the MIT License. Check license file for more info.
